unit JobSettings;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  ExtCtrls, StdCtrls, ComCtrls, JobLib;

type
  TJobForm = class(TForm)
    JDoIt: TCheckBox;
    LIn: TLabel;
    LOut: TLabel;
    JIn: TEdit;
    JOut: TEdit;
    BBrowse: TButton;
    LFormat: TLabel;
    JFormat: TLabel;
    MainFrame: TBevel;
    ID3Frame: TBevel;
    JAddTag: TCheckBox;
    LTitle: TLabel;
    LArtist: TLabel;
    LAlbum: TLabel;
    LYear: TLabel;
    LGenre: TLabel;
    LComment: TLabel;
    JTitle: TEdit;
    JArtist: TEdit;
    JAlbum: TEdit;
    JYear: TEdit;
    JGenre: TComboBox;
    JComment: TEdit;
    JUseTrack: TCheckBox;
    JTrack: TEdit;
    JTrackCtl: TUpDown;
    JAutoAdvance: TCheckBox;
    BOK: TButton;
    BCancel: TButton;
    JSaveDialog: TSaveDialog;
    JAlbumMode: TCheckBox;
    LAlbumMode: TLabel;
    procedure BBrowseClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure UpdateID3(Sender: TObject);
    procedure UpdateMain(Sender: TObject);
    procedure UpdateV11(Sender: TObject);
  private
    { Private-Deklarationen }
    function FindGenre(GenreInList:integer):integer;
  public
    { Public-Deklarationen }
    procedure ImportJob(const Job:TJob;FileNo,FileMax:integer);
    procedure ExportJob(var Job:TJob);
  end;

var
  JobForm: TJobForm;

{$I GenreList.inc}

implementation

{$R *.DFM}

procedure TJobForm.ImportJob(const Job:TJob;FileNo,FileMax:integer);
begin
  Caption:='Job-Einstellungen ('+IntToStr(FileNo)+'/'+IntToStr(FileMax)+')';
  if FileNo=FileMax
    then BOK.Caption:='Fertig >>'
    else BOK.Caption:='Nchste Datei >>';
  with Job do begin
    JDoIt.Checked:=ReallyEncode;
    JIn.Text:=SourceFile;
    JIn.SelStart:=length(SourceFile);
    JOut.Text:=DestFile;
    case InputType of
      Wave:JFormat.Caption:='Windows Wave';
      Layer1:JFormat.Caption:='MPEG Audio Layer I';
      Layer2:JFormat.Caption:='MPEG Audio Layer II';
      Layer3:JFormat.Caption:='MPEG Audio Layer III';
      Ogg:JFormat.Caption:='Ogg Vorbis';
      PCM:JFormat.Caption:='Raw PCM';
    end;
    JTitle.Text:='';
    if not JAlbumMode.Checked then begin
      JArtist.Text:='';
      JAlbum.Text:='';
      JYear.Text:='';
      JGenre.ItemIndex:=0;
      JComment.Text:='';
    end;
    if JAutoAdvance.Checked then
      JTrackCtl.Position:=StrToInt(JTrack.Text)+1;
  end;
  UpdateMain(nil);
end;

procedure TJobForm.ExportJob(var Job:TJob);
begin
  with Job do begin
    DestFile:=JOut.Text;
    ReallyEncode:=JDoIt.Checked;
    AddID3Tag:=JAddTag.Checked;
    with ID3Info do begin
      Title:=JTitle.Text;
      Artist:=JArtist.Text;
      Album:=JAlbum.Text;
      Year:=JYear.Text;
      Genre:=FindGenre(JGenre.ItemIndex);
      if JUseTrack.Checked
        then Track:=StrToInt(JTrack.Text)
        else Track:=0;
      Comment:=JComment.Text;
    end;
  end;
end;

function TJobForm.FindGenre(GenreInList:integer):integer;
var s:string; i,res:integer;
begin
  res:=-1;
  s:=JGenre.Items[GenreInList];
  i:=Low(GenreList);
  while (res<0) AND (i<=High(GenreList)) do begin
    if GenreList[i]=s then res:=i;
    inc(i);
  end;
  if res<0 then res:=0;
  FindGenre:=res;
end;

procedure TJobForm.BBrowseClick(Sender: TObject);
begin
  with JSaveDialog do begin
    FileName:=JOut.Text;
    if Execute then
      JOut.Text:=FileName;
  end;
end;

procedure TJobForm.FormCreate(Sender: TObject);
var i:integer;
begin
  for i:=Low(GenreList) to High(GenreList) do begin
    JGenre.Items.Add(GenreList[i]);
  end;
  JGenre.ItemIndex:=0;
end;

procedure TJobForm.UpdateID3(Sender: TObject);
var m:boolean;
begin
  m:=JAddTag.Checked AND JDoIt.Checked;
  LTitle.Enabled:=m;
  JTitle.Enabled:=m;
  LArtist.Enabled:=m;
  JArtist.Enabled:=m;
  LAlbum.Enabled:=m;
  JAlbum.Enabled:=m;
  LYear.Enabled:=m;
  JYear.Enabled:=m;
  LGenre.Enabled:=m;
  JGenre.Enabled:=m;
  LComment.Enabled:=m;
  JComment.Enabled:=m;
  JUseTrack.Enabled:=m;
  JAlbumMode.Enabled:=m;
  LAlbumMode.Enabled:=m;
  UpdateV11(nil);
end;

procedure TJobForm.UpdateMain(Sender: TObject);
var m:boolean;
begin
  m:=JDoIt.Checked;
  LIn.Enabled:=m;
  JIn.Enabled:=m;
  LOut.Enabled:=m;
  JOut.Enabled:=m;
  BBrowse.Enabled:=m;
  LFormat.Enabled:=m;
  JFormat.Enabled:=m;
  JAddTag.Enabled:=m;
  UpdateID3(nil);
end;

procedure TJobForm.UpdateV11(Sender: TObject);
var m:boolean;
begin
  m:=JUseTrack.Checked;
  if m then begin
    JComment.MaxLength:=28;
    JComment.Text:=copy(JComment.Text,1,28);
  end else
    JComment.MaxLength:=30;
  m:=m AND JAddTag.Checked AND JDoIt.Checked;
  JTrack.Enabled:=m;
  JTrackCtl.Enabled:=m;
  JAutoAdvance.Enabled:=m;
end;

end.
