unit Main;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ComCtrls, INIfiles, ExtCtrls, Buttons, ShellAPI,
  PresetLib, JobLib, CoreLib;

const WM_FILESDROPPED=WM_USER+123;

type
  TMainForm = class(TForm)
    LPreset: TLabel;
    SPreset: TComboBox;
    SModeBox: TGroupBox;
    SMCBR: TRadioButton;
    SMABR: TRadioButton;
    SMVBRold: TRadioButton;
    SMVBRmix: TRadioButton;
    SMVBRnew: TRadioButton;
    SChanBox: TGroupBox;
    SCAuto: TRadioButton;
    SCMono: TRadioButton;
    SCStereo: TRadioButton;
    SCJS: TRadioButton;
    SCForce: TRadioButton;
    SCJSAuto: TRadioButton;
    SQualBox: TGroupBox;
    SQuality: TTrackBar;
    LQuality: TLabel;
    SCBRBox: TGroupBox;
    SVBRBox: TGroupBox;
    SVBRQual: TTrackBar;
    LVBRQual: TLabel;
    SCBRRate: TComboBox;
    LCBRRate: TLabel;
    SVBRMax: TComboBox;
    LVBRMax: TLabel;
    SVBRMin: TComboBox;
    LVBRMin: TLabel;
    SVBRTag: TCheckBox;
    SVBRForce: TCheckBox;
    SRateBox: TGroupBox;
    SRateA1: TRadioButton;
    SRateB1: TRadioButton;
    SRateC1: TRadioButton;
    SRateA2: TRadioButton;
    SRateB2: TRadioButton;
    SRateC2: TRadioButton;
    SRateA4: TRadioButton;
    SRateB4: TRadioButton;
    SRateC4: TRadioButton;
    LRate1: TLabel;
    LRate2: TLabel;
    LRate4: TLabel;
    LRateA: TLabel;
    LRateB: TLabel;
    LRateC: TLabel;
    LRate: TLabel;
    SHdrBox: TGroupBox;
    SCopyrighted: TCheckBox;
    SOriginal: TCheckBox;
    SCRC: TCheckBox;
    SRes: TCheckBox;
    SMaskBox: TGroupBox;
    SATHOnly: TCheckBox;
    SNoShort: TCheckBox;
    SVoice: TCheckBox;
    SFilterBox: TGroupBox;
    SNoFilters: TCheckBox;
    SFHPen: TCheckBox;
    SFHPWen: TCheckBox;
    SFHPwfreq: TEdit;
    SFHPfreq: TEdit;
    SFLPfreq: TEdit;
    SFLPWfreq: TEdit;
    SFLPen: TCheckBox;
    SFLPWen: TCheckBox;
    Hz1: TLabel;
    Hz2: TLabel;
    Hz3: TLabel;
    Hz4: TLabel;
    SFreeForm: TCheckBox;
    SStrictISO: TCheckBox;
    BAdd: TButton;
    BDel: TButton;
    LVBRQualX: TLabel;
    SID3: TCheckBox;
    SImmed: TCheckBox;
    Logo: TPanel;
    LLogo1: TLabel;
    LLogo2: TLabel;
    BInfo: TSpeedButton;
    SRateAuto: TRadioButton;
    procedure FormCreate(Sender: TObject);
    procedure UpdateMode(Sender: TObject);
    procedure UpdateQuality(Sender: TObject);
    procedure UpdateVBRQuality(Sender: TObject);
    procedure UpdateRate(Sender: TObject);
    procedure UpdateFilters(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure UpdateID3(Sender: TObject);
    procedure BAddClick(Sender: TObject);
    procedure SPresetClick(Sender: TObject);
    procedure BDelClick(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure FormHide(Sender: TObject);
    procedure BInfoClick(Sender: TObject);
  private
    { Private-Deklarationen }
    procedure UpdateAll;
    procedure DropFileHandler(var msg:TMessage);message WM_DROPFILES;
    procedure OnFileDrop(var msg:TMessage);message WM_FILESDROPPED;
  public
    { Public-Deklarationen }
  end;

var
  MainForm: TMainForm;
  Config:TINIFile;

implementation

uses Info;

{$R *.DFM}

procedure PrepareRateSelect(var ctl:TComboBox);
var i,r:integer; s:string[5];
begin
  for i:=0 to 17 do begin
    r:=Bitrates[i];
    str(r,s);
    if r<10 then s:=#32#32+s;
    if r<100 then s:=#32#32+s;
    ctl.Items.Add(s);
  end;
end;

procedure TMainForm.FormCreate(Sender: TObject);
var InitialSettings:TSettings;
    TempHint:string;
begin
//AllocConsole;
  if not HaveLAME then
    ShowMessage('Es wurde keine LAME.EXE im aktuellen Verzeichnis gefunden.'^M+
                'Daher knnen keine Dateien codiert werden.'^M^M+
                'Bitte klicken Sie auf das kleine MP3-Symbol in der Programmoberflche,'^M+
                'um zu erfahren, woher man eine LAME.EXE bekommen kann.');

  PrepareRateSelect(SCBRRate);
  PrepareRateSelect(SVBRMin);
  PrepareRateSelect(SVBRMax);

  Config:=TINIFile.Create('.\LAMEr389.ini');
  if Config.SectionExists('*LastSettings')
    then ConfigToSettings(InitialSettings,'*LastSettings')
    else InitialSettings:=DefaultPreset.Settings;
  SettingsToForm(InitialSettings);

  LoadPresets;
  UpdatePresetList;
  LastPreset:=Config.ReadString('*General','LastPreset','');
  FindLastPreset;

  SID3.Checked:=Config.ReadBool('*General','AddID3Tags',false);
  SImmed.Checked:=Config.ReadBool('*General','QueryBeforeEncode',true);

  {$DEFINE HINTS_MAINFORM}
    {$I Hints.inc}
  {$UNDEF HINTS_MAINFORM}

  UpdateAll;
end;

{$I UpdateControls.inc}

procedure TMainForm.FormDestroy(Sender: TObject);
var curr:TSettings;
begin
  FormToSettings(curr);
  SettingsToConfig(curr,'*LastSettings');

  with Config do begin
    WriteString('*General','LastPreset',LastPreset);
    WriteBool('*General','AddID3Tags',SID3.Checked);
    WriteBool('*General','QueryBeforeEncode',SImmed.Checked);
    Free;
  end;
end;

procedure TMainForm.BAddClick(Sender: TObject);
var Index:integer;
    Settings:TSettings;
begin
  FormToSettings(Settings);
  Index:=SPreset.Items.IndexOf(SPreset.Text);
  if Index<0 then begin
    LastPreset:=SPreset.Text;
    AddPreset(Settings,LastPreset);
    UpdatePresetList;
  end else begin
    if MessageDlg('Bestehendes Preset '^M'"'+SPreset.Text+'"'^M'berschreiben?',
       mtConfirmation,[mbYes,mbNo],0)<>mrYes then exit;
    LastPreset:=SPreset.Text;
    ReplacePreset(Settings,Index);
  end;
end;

procedure TMainForm.SPresetClick(Sender: TObject);
var Index:integer;
begin
  LastPreset:=SPreset.Text;
  Index:=SPreset.Items.IndexOf(LastPreset);
  SettingsToForm(Presets[Index].Settings);
  UpdateAll;
end;

procedure TMainForm.BDelClick(Sender: TObject);
var Index:integer;
begin
  Index:=SPreset.Items.IndexOf(SPreset.Text);
  if Index<0 then exit;
  if MessageDlg('Preset '^M'"'+SPreset.Text+'"'^M'lschen?',
     mtConfirmation,[mbYes,mbNo],0)<>mrYes then exit;
  DeletePreset(Index);
  UpdatePresetList;
end;

procedure TMainForm.DropFileHandler(var msg:TMessage);
var Drop:HDROP;
    DropBuf:array[0..255]of char;
    DCount,DPos:integer;
begin
  Drop:=msg.wParam;
  DCount:=DragQueryFile(Drop,Cardinal(-1),nil,0);
  InitAddJobs(DCount);
  for DPos:=0 to (DCount-1) do begin
    DragQueryFile(Drop,DPos,@DropBuf[0],255);
    AddJob(DropBuf);
  end;
  DoneAddJobs;
  DragFinish(Drop);
  msg.Result:=0;
  PostMessage(Handle,WM_FILESDROPPED,0,0);
end;

procedure TMainForm.FormShow(Sender: TObject);
begin
  DragAcceptFiles(Handle,true);
end;

procedure TMainForm.FormHide(Sender: TObject);
begin
  DragAcceptFiles(Handle,false);
end;

procedure TMainForm.OnFileDrop(var msg:TMessage);
var JobNo:integer; Canceled:boolean;
begin
  if not HaveLAME then exit;
  FormToSettings(EncodeSettings);
  Hide;
  if SID3.Checked then begin
    if SImmed.Checked then begin
      if QueryAll then EncodeAll;
    end else begin
      Canceled:=false; JobNo:=0;
      while not(Canceled) AND (JobNo<=High(Jobs)) do begin
        if QueryJob(JobNo) then ExecuteJob(Jobs[JobNo])
                           else Canceled:=true;
        inc(JobNo);
      end;
    end;
  end else
    EncodeAll;
  Show;
end;

procedure TMainForm.BInfoClick(Sender: TObject);
begin
  InfoForm.ShowModal;
end;

end.
