unit PresetLib;
interface
uses SysUtils,Classes,StdCtrls;

const Bitrates:array[0..17]of integer=
        (8,16,24,32,40,48,56,64,80,96,112,128,144,160,192,224,256,320);

type TEncMode=(CBR,ABR,VBR_old,VBR_mtrh,VBR_new);
     TChannels=(Auto,Mono,Stereo,Joint,ForceJS,AutoJS);

type TVBRSettings=record
                    MinRate,MaxRate:byte;
                    HardLimit:boolean;
                    AddTag:boolean;
                    Quality:byte;
                  end;

type TFilter=record
               Enabled:boolean;
               Freq:word;
             end;

type TFilterSettings=record
                       NoFilters:boolean;
                       Lowpass:TFilter;
                       LowpassWidth:TFilter;
                       Highpass:TFilter;
                       HighpassWidth:TFilter;
                     end;

type TMaskOptions=record
                    ATHOnly:boolean;
                    NoShortBlocks:boolean;
                    VoiceMode:boolean;
                  end;

type TStreamOptions=record
                      Original:boolean;
                      Copyrighted:boolean;
                      AddCRC:boolean;
                      UseBitRes:boolean;
                      FreeForm:boolean;
                      StrictISO:boolean;
                    end;

type TSettings=record
                 EncMode:TEncMode;
                 Channels:TChannels;
                 Quality:byte;
                 CBRRate:byte;
                 VBRSettings:TVBRSettings;
                 SampleRate:byte;
                 FilterSettings:TFilterSettings;
                 MaskOptions:TMaskOptions;
                 StreamOptions:TStreamOptions;
               end;

type TPreset=record
               Name:string[127];
               Settings:TSettings;
             end;

{$I DefaultPreset.inc}

var Presets:array of TPreset;
    LastPreset:string;

procedure FormToSettings(var Settings:TSettings);
procedure SettingsToConfig(const Settings:TSettings;const Name:string);
procedure ConfigToSettings(var Settings:TSettings;const Name:string);
procedure SettingsToForm(const Settings:TSettings);

procedure LoadPresets;
procedure UpdatePresetList;
procedure FindLastPreset;

procedure AddPreset(const Settings:TSettings;const Name:string);
procedure ReplacePreset(const Settings:TSettings;Index:integer);
procedure DeletePreset(Index:integer);

implementation
uses Main;

{$I FormToSettings.inc}
{$I SettingsToConfig.inc}
{$I ConfigToSettings.inc}
{$I SettingsToForm.inc}

procedure LoadPresets;
var Sections:TStringList;
    PMax,PCount:integer;
begin
  with Config do begin
    Sections:=TStringList.Create;
    ReadSections(Sections);
    // remove global config sections
    PCount:=0;
    while PCount<Sections.Count do begin
      if Sections[PCount][1]='*'
        then Sections.Delete(PCount)
        else inc(PCount);
    end;
    // prepare preset list
    PMax:=Sections.Count;
    SetLength(Presets,PMax);
    for PCount:=0 to (PMax-1) do begin
      Presets[PCount].Name:=Sections[PCount];
      ConfigToSettings(Presets[PCount].Settings,Sections[PCount]);
    end;
    Sections.Free;
  end;
  // no preset => use default
  if PMax<1 then begin
    SetLength(Presets,1);
    Presets[0]:=DefaultPreset;
    SettingsToConfig(DefaultPreset.Settings,DefaultPreset.Name);
  end;
end;

procedure UpdatePresetList;
var i:integer;
begin
  with MainForm.SPreset.Items do begin
    Clear;
    for i:=0 to High(Presets) do
      Add(Presets[i].Name);
  end;
end;

procedure FindLastPreset;
var i:integer;
begin
  with MainForm.SPreset do begin
    i:=Items.IndexOf(LastPreset);
    if i<0 then i:=0;
    LastPreset:=Presets[i].Name;
    Text:=LastPreset;
  end;
end;

procedure AddPreset(const Settings:TSettings;const Name:string);
var Index:integer;
begin
  Index:=High(Presets)+1;
  SetLength(Presets,Index+1);
  Presets[Index].Name:=Name;
  Presets[Index].Settings:=Settings;
  SettingsToConfig(Settings,Name);
end;

procedure ReplacePreset(const Settings:TSettings;Index:integer);
begin
  Presets[Index].Settings:=Settings;
  SettingsToConfig(Settings,Presets[Index].Name);
end;

procedure DeletePreset(Index:integer);
var Max,i:integer;
begin
  Config.EraseSection(Presets[Index].Name);
  Max:=High(Presets);
  if Index<Max then
    for i:=(Index+1) to Max do
      Presets[i-1]:=Presets[i];
  SetLength(Presets,Max);
end;

initialization
  LastPreset:='';
  SetLength(Presets,0);
end.
